import SkribblClient from "./SkribblClient.js";

/**
 * Custom element `<skribbl-player-list>` for the player list that appears in the lobby of a game.
 */
export default class SkribblPlayerList extends HTMLElement {
	/**
	 * Constructs a new SkribblPlayerList for the given client. The list is automatically updated as players join and leave.
	 * @param {SkribblClient} client
	 */
	constructor(client,{compact=false}={}){
		super();
		this.attachShadow({mode:"open"});
		this.shadowRoot.innerHTML = `
			<style>
				:host {
					display: block;
				}
				:host(:not([compact])) {
					margin: 10px;
					color: #ffffff;
					text-shadow: 0 0 5px #00000080;
				}
				:host(:not([compact])) > span {
					display: inline-block;
					width: 100px;
					margin: 0 10px 10px 0;
					text-align: center;
				}
				:host([compact]) > span {
					display: block;
					width: 100%;
					padding: 5px;
					box-sizing: border-box;
					background: #ffffff;
					border-radius: 3px;
					margin: 0 0 3px 0;
				}
				span.name {
					font-wheight: bold;
				}
				:host(:not([compact])) span.points {
					display: none;
				}
			</style>
		`;
		this._span = this.shadowRoot.querySelector("span");
		client.onPlayersListChange(players=>{
			let oldSpans = this.shadowRoot.querySelectorAll(":host > span");
			Array.from(oldSpans).forEach(span=>span.remove());
			players.forEach(({name,points=0})=>{
				let span = document.createElement("span");
				span.innerHTML = `
					<span class="name"></span><br>
					<span class="points"></span>
				`;
				span.querySelector(".name").textContent = name;
				span.querySelector(".points").textContent = points.toString();
				this.shadowRoot.appendChild(span);
			});
		});
		this.compact = compact;
	}

	set compact(compact){
		this.toggleAttribute("compact",compact);
	}

	get compact(){
		return this.hasAttribute("compact");
	}
}
customElements.define("skribbl-player-list",SkribblPlayerList);